@@ -57,7 +57,7 @@ class PandasDoggo:
 
     - read / write csv and parquet files
     - read and write both locally and to s3
-    - support gzip and zip compression
+    - support gzip, snappy and zip compression
     - sensible s3 handling of different profiles / credentials
 
     Usage
@@ -105,6 +105,8 @@ class PandasDoggo:
 
         if path.endswith('.gzip') or path.endswith('.gz'):
             return 'gzip'
+        if ('.snappy.' in path) or ('.sz.' in path):
+            return 'snappy'
         if path.endswith('.zip'):
             return 'zip'
 
@@ -114,7 +116,7 @@ class PandasDoggo:
         :param path: required. Can be s3 or local s3 must be in `s3://` format - accepts `S3Location`
         :type path: str
         :param file_format: None. Autodetects from path, can be set to `csv` or `parquet` to explicitly force a format
-        :param compression: optional, 'gzip' or None. Autodetects from path if path ends in `.gz` or `.gzip`
+        :param compression: optional, 'gzip', 'snappy' or None. Autodetects from path if path ends in `.gz`, `.gzip` or contains `.snappy`
         :param args: args to pass to the panda to load the file
         :param kwargs: kwargs to pass to the panda to load the file eg columns=['subset', 'of', 'columns']
         :return: Pandas.DataFrame
@@ -144,7 +146,7 @@ class PandasDoggo:
         return df
 
     def load_parquet(self, path, compression=None, *args, **kwargs):
-        """alias for .load(path, format='csv')"""
+        """alias for .load(path, format='parquet')"""
 
         compression = compression or self._extract_compression(path)
         fm = FileDoggo(path, mode='rb', client=self.s3_client, compression=compression)
@@ -161,7 +163,7 @@ class PandasDoggo:
         :param path: required. Can be s3 or local s3 must be in `s3://` format - accepts `S3Location`
         :type path: str
         :param file_format: 'None. Autodetects from path, can be set to `csv` or `parquet` to explicitly force a format
-        :param compression: None. Supports gzip, autodetects from path if path ends in `.gz` or `.gzip`
+        :param compression: None. Supports gzip and snappy, autodetects from path if path ends in `.gz`, `.gzip` or contains `.snappy`
         :param args: args to pass to the panda to save the file
         :param kwargs: kwargs to pass to the panda to load the file eg index=None
         """
@@ -183,6 +185,8 @@ class PandasDoggo:
 
     def save_parquet(self, df, path, compression=None, *args, **kwargs):
         """Alias for .save(df, format='parquet')"""
+
+        compression = compression or self._extract_compression(path)
         fm = FileDoggo(path, mode='wb', client=self.s3_client, compression=compression)
         with fm as f:
             df.to_parquet(f, *args, **kwargs)
@@ -218,7 +222,7 @@ This is written to treat local paths and s3 paths the same, returning a file lik
         :param is_s3: force Doggo to treat path as an S3Location, otherwise autodetects if beings with "s3://"
         :type is_s3: bool
         :param client: optional `boto3.Session().Client('s3')` instance to use for s3 operations
-        :param compression: None or 'gzip'.
+        :param compression: None, 'gzip' or 'snappy'.
         """
 
         self.buffer = BytesIO()
@@ -232,7 +236,7 @@ This is written to treat local paths and s3 paths the same, returning a file lik
             self.path = path
 
         self._client = client
-        if compression in [None, 'gzip']:
+        if compression in [None, 'gzip', 'snappy']:
             self.compression = compression
         else:
             raise NotImplementedError(f"Compression {compression} is not supported in FileDoggo")
