@@ -1,8 +1,5 @@
-"""
-(c) Dativa 2012-2020, all rights reserved
-
-This code is licensed under MIT license (see license.txt for details)
-"""
+# (c) Deductive 2012-2020, all rights reserved
+# This code is licensed under MIT license (see license.txt for details)
 
 import sqlite3
 import os
@@ -11,7 +8,9 @@ from time import time
 from datetime import datetime, timedelta
 
 from .base_test import BaseTest
-from newtools import CachedPep249Query, CachedAthenaQuery, BaseCachedQuery, PandasDoggo, DoggoFileSystem
+from newtools import CachedPep249Query, CachedAthenaQuery, BaseCachedQuery, PandasDoggo, DoggoFileSystem, log_to_stdout
+
+log_to_stdout("newtools")
 
 
 class TestCachedQuery(BaseTest):
@@ -60,7 +59,7 @@ class TestCachedQuery(BaseTest):
                               gzip=False)
         self.set_timeouts(q)
 
-        with self.assertLogs("dativa.attribution.cached_query", level="INFO") as cm:
+        with self.assertLogs("newtools.cached_query", level="INFO") as cm:
             q.get_results(sql_file="test_select.sql",
                           output_prefix="test_query_1_row",
                           params={
@@ -68,7 +67,7 @@ class TestCachedQuery(BaseTest):
                           }
                           )
 
-        self.assertIn('INFO:dativa.attribution.cached_query:secret = *********', cm.output)
+        self.assertIn('INFO:newtools.cached_query:secret = *********', cm.output)
 
     def test_cache_pep249(self):
         q = CachedPep249Query(self.sqlite_db,
